<?php

namespace Drupal\Tests\sparql_entity_storage\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\sparql_test\Entity\SparqlTest;
use Drupal\Tests\sparql_entity_storage\Traits\SparqlConnectionTrait;

/**
 * Tests the SPARQL serializer.
 *
 * @group sparql_entity_storage
 */
class SparqlSerializerTest extends KernelTestBase {

  use SparqlConnectionTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'rdf_taxonomy',
    'rest',
    'serialization',
    'sparql_entity_serializer_test',
    'sparql_entity_storage',
    'taxonomy',
    'user',
  ];

  /**
   * {@inheritdoc}
   */
  protected function bootEnvironment() {
    parent::bootEnvironment();
    $this->setUpSparql();
  }

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    $this->installConfig(['sparql_entity_storage', 'sparql_entity_serializer_test']);
  }

  /**
   * Tests content negotiation.
   */
  public function testContentNegotiation() {
    $entity = SparqlTest::create([
      'rid' => 'fruit',
      'id' => 'http://example.com/apple',
      'label' => 'Apple',
    ]);
    $entity->save();

    $encoders = $this->container->getParameter('sparql_entity.encoders');
    $serializer = $this->container->get('sparql_entity.serializer');
    foreach ($encoders as $format => $content_type) {
      $serialized = trim($serializer->serializeEntity($entity, $format));
      $expected = trim(file_get_contents(__DIR__ . "/../../fixtures/content-negotiation/rdf_entity/$format"));
      $this->assertEquals($expected, $serialized);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function tearDown() {
    SparqlTest::load('http://example.com/apple')->delete();
    parent::tearDown();
  }

}
